package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.DERUTF8String;
import java.util.Enumeration;
import java.util.Vector;

public class IetfAttrSyntax extends ASN1Encodable {
   public static final int VALUE_OCTETS = 1;
   public static final int VALUE_OID = 2;
   public static final int VALUE_UTF8 = 3;
   GeneralNames policyAuthority = null;
   Vector values = new Vector();
   int valueChoice = -1;

   public IetfAttrSyntax(ASN1Sequence seq) {
      byte var2 = 0;
      if (seq.getObjectAt(0) instanceof ASN1TaggedObject) {
         this.policyAuthority = GeneralNames.getInstance((ASN1TaggedObject)seq.getObjectAt(0), false);
         var2 = 1;
      } else if (seq.size() == 2) {
         this.policyAuthority = GeneralNames.getInstance(seq.getObjectAt(0));
         var2 = 1;
      }

      if (seq.getObjectAt(var2) instanceof ASN1Sequence) {
         Enumeration seq1 = ((ASN1Sequence)seq.getObjectAt(var2)).getObjects();

         while(seq1.hasMoreElements()) {
            byte var3;
            DERObject var5;
            if ((var5 = (DERObject)seq1.nextElement()) instanceof DERObjectIdentifier) {
               var3 = 2;
            } else if (var5 instanceof DERUTF8String) {
               var3 = 3;
            } else {
               if (!(var5 instanceof DEROctetString)) {
                  throw new IllegalArgumentException("Bad value type encoding IetfAttrSyntax");
               }

               var3 = 1;
            }

            if (this.valueChoice < 0) {
               this.valueChoice = var3;
            }

            if (var3 != this.valueChoice) {
               throw new IllegalArgumentException("Mix of value types in IetfAttrSyntax");
            }

            this.values.addElement(var5);
         }

      } else {
         throw new IllegalArgumentException("Non-IetfAttrSyntax encoding");
      }
   }

   public GeneralNames getPolicyAuthority() {
      return this.policyAuthority;
   }

   public int getValueType() {
      return this.valueChoice;
   }

   public Object[] getValues() {
      int var1;
      int var3;
      if (this.getValueType() == 1) {
         ASN1OctetString[] var5 = new ASN1OctetString[var1 = this.values.size()];

         for(var3 = 0; var3 != var1; ++var3) {
            var5[var3] = (ASN1OctetString)this.values.elementAt(var3);
         }

         return var5;
      } else if (this.getValueType() == 2) {
         DERObjectIdentifier[] var4 = new DERObjectIdentifier[var1 = this.values.size()];

         for(var3 = 0; var3 != var1; ++var3) {
            var4[var3] = (DERObjectIdentifier)this.values.elementAt(var3);
         }

         return var4;
      } else {
         DERUTF8String[] var2 = new DERUTF8String[var1 = this.values.size()];

         for(var3 = 0; var3 != var1; ++var3) {
            var2[var3] = (DERUTF8String)this.values.elementAt(var3);
         }

         return var2;
      }
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      GeneralNames var2;
      if ((var2 = this.policyAuthority) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(0, var2);
         var1.add(var3);
      }

      IetfAttrSyntax var10000 = this;
      ASN1EncodableVector var4;
      var4 = new ASN1EncodableVector.<init>();
      Enumeration var5 = var10000.values.elements();

      while(var5.hasMoreElements()) {
         var4.add((ASN1Encodable)var5.nextElement());
      }

      DERSequence var6;
      var6 = new DERSequence.<init>(var4);
      var1.add(var6);
      return new DERSequence(var1);
   }
}
